@@ -5,8 +5,8 @@ use warnings;
 use 5.008001;
 use base qw( Alien::Base );
 
-# ABSTRACT: Find or download or build cmake 3 or better
-our $VERSION = '0.08'; # VERSION
+# ABSTRACT: Find or download or build cmake 3
+our $VERSION = '0.10'; # VERSION
 
 
 sub exe
@@ -37,11 +37,11 @@ __END__
 
 =head1 NAME
 
-Alien::cmake3 - Find or download or build cmake 3 or better
+Alien::cmake3 - Find or download or build cmake 3
 
 =head1 VERSION
 
-version 0.08
+version 0.10
 
 =head1 SYNOPSIS
 
@@ -71,7 +71,7 @@ From L<alienfile>
 =head1 DESCRIPTION
 
 This L<Alien> distribution provides an external dependency on the build tool C<cmake>
-version 3.0.0 or better.  C<cmake> is a popular alternative to autoconf.
+version 3.x.x.  C<cmake> is a popular alternative to autoconf.
 
 =head1 METHODS
 
@@ -115,7 +115,7 @@ these ways:
 
 It integrates better with L<Alien>s that are based on that technology.
 
-=item L<Alien::cmake3> will provide version 3.0.0 or better
+=item L<Alien::cmake3> will provide version 3.x.x
 
 L<Alien::CMake> will provide 2.x.x on some platforms where more recent binaries are not available.
 
@@ -149,7 +149,7 @@ binary share install (even if available), and instead a source share install.
 
 =head1 CAVEATS
 
-If you do not have a system C<cmake> of at least 3.0.0 available, then a share install
+If you do not have a system C<cmake> version 3.x.x available, then a share install
 will be attempted.
 
 Binary share installs are attempted on platforms for which the latest version of C<cmake>
@@ -167,7 +167,7 @@ you have some options:
 
 =item Install system version of C<cmake>
 
-If you can find an older version better than 3.0.0 that is supported by your operating
+If you can find an older version of C<cmake> 3.x.x that is supported by your operating
 system.
 
 =item Force a source code install
@@ -189,9 +189,11 @@ Contributors:
 
 Adriano Ferreira (FERREIRA)
 
+Dagfinn Ilmari Mannsåker (ilmari)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by Graham Ollis.
+This software is copyright (c) 2017-2024 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
